@@ -1,11 +1,12 @@
 // Copyright 2018 Mathew Robinson <chasinglogic@gmail.com>. All rights reserved. Use of this source code is
 // governed by the Apache-2.0 license that can be found in the LICENSE file.
 
-
 #[macro_use]
 extern crate serde_derive;
 
+extern crate chrono;
 extern crate dirs;
+extern crate serde_json;
 extern crate tabwriter;
 
 extern crate taskforge;
